@@ -110,6 +110,7 @@ class CrabWeb:
             submit_config=None, submit_relink=None,
             submit_confirm=None, submit_cancel=None,
             orphan=None, graceperiod=None, timeout=None,
+            crabid=None,
 
             submit_notify=None, **kwargs):
         """Displays information about a current job.
@@ -209,6 +210,58 @@ class CrabWeb:
                         'description': 'Reset the job status?',
                         'target': '/job/' + str(id_) + '/clear'})
 
+        elif command == 'delete':
+            notdeleted = info['deleted'] is None
+            if submit_confirm:
+                if notdeleted:
+                    self.store.delete_job(id_)
+                else:
+                    self.store.undelete_job(id_)
+
+                raise HTTPRedirect('/job/' + str(id_))
+
+            elif submit_cancel:
+                raise HTTPRedirect('/job/' + str(id_))
+
+            else:
+                return self._write_template('confirm.html',
+                       {'id': id_, 'info': info,
+                       'title': 'delete' if notdeleted else 'undelete',
+                       'description': ('Delete' if notdeleted else 'Undelete') +
+                                       ' this job from the server?',
+                       'target': '/job/' + str(id_) + '/delete'})
+
+        elif command == 'changeid':
+            if submit_confirm:
+                if crabid != '':
+                    if self.store.get_jobs(info['host'], info['user'],
+                            include_deleted=True, crabid=crabid):
+                        raise HTTPError(400, 'Specified job ID already exists.')
+                    else:
+                        self.store.update_job(id_, crabid=crabid)
+                        raise HTTPRedirect('/job/' + str(id_))
+                else:
+                    raise HTTPError(400, 'Specified job ID is blank.')
+
+            elif submit_cancel:
+                raise HTTPRedirect('/job/' + str(id_))
+
+            else:
+                return self._write_template('confirm.html',
+                       {'id': id_, 'info': info,
+                       'title': 'change identifier',
+                       'description': 'Change Job ID for this job?  Please note '
+                                      'that the ID which will be used to report '
+                                      'events related to this job should be '
+                                      'updated at the same time to ensure that '
+                                      'the job continues to be correctly '
+                                      'identified.  This should be done in the '
+                                      'crontab if the CRABID variable is used, '
+                                      'or in the cron job itself in the case '
+                                      'of Crab-aware cron jobs.',
+                       'target': '/job/' + str(id_) + '/changeid',
+                       'data': {'crabid': crabid}})
+
         elif command == 'output':
             finishid_next = None
             finishid_prev = None
